@@ -3,7 +3,7 @@ package Test::Dirs;
 use warnings;
 use strict;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 use base 'Exporter';
 our @EXPORT = qw(
@@ -21,6 +21,7 @@ use List::MoreUtils 'any';
 use Text::Diff 'diff';
 use Path::Class;
 use File::Path 2.07 'remove_tree';
+use Test::Harness;
 
 our $test = Test::Builder->new;
 
@@ -48,6 +49,9 @@ sub is_dir {
 	my $ignore_ref = shift || [];
 	my $verbose = shift;
 
+	$verbose = $Test::Harness::Verbose
+		unless defined($verbose);
+
 	if ( $ENV{FIXIT} ) {
 		dircopy( $dir1, $dir2 )
 			or die 'failed to copy '
@@ -59,6 +63,13 @@ sub is_dir {
 		return;
 	}
 
+	my $have_two_folders = -d $dir1 && -d $dir2;
+	unless ($have_two_folders) {
+		$test->ok( -d $dir2, 'expected-param "' . $dir2 . '" is directory' );
+		$test->ok( -d $dir1, 'is-param "' . $dir1 . '" is directory' );
+		return;
+	}
+
 	my @ignore_files = @{$ignore_ref};
 	my @differences;
 	File::DirCompare->compare($dir1, $dir2, sub {
@@ -168,7 +179,7 @@ Test::Dirs - easily copy and compare folders inside tests
 		is_dir($src_dir, $tmp_dir, 'fails without @ignore_files');
 	};
 	
-	# be verbose, print out the diff if doesn't match
+	# force verbose, print out the diff if doesn't match
 	is_dir($src_dir, $tmp_dir, 'test with verbose on', \@ignore_files, 'verbose');
 	
 =head1 DESCRIPTION
@@ -216,6 +227,7 @@ content into C<$expected_dir>. Usefull for bootstraping test results or for
 acnkowledging results after code update.
 
 C<$message>, C<\@ignore_files>, C<$verbose> are optional.
+Default verbose value is C<$Test::Harness::Verbose>.
 
 =head2 dir_cleanup_ok($filename, $message)
 
